==> Goober_0_5_0.tar.gz: goober-bb10/translations/Goober.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>LoginSheet</name>
    <message>
        <location filename="../assets/LoginSheet.qml" line="47"/>
        <source>Sign In</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewPostSheet</name>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="35"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="44"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="50"/>
        <source>New Post</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostItem</name>
    <message>
        <location filename="../assets/PostItem.qml" line="138"/>
        <source>&lt;i&gt;{{POST DELETED}}&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="168"/>
        <source>Reply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="177"/>
        <source>Reply All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="187"/>
        <source>Add Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="187"/>
        <source>Delete Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="198"/>
        <source>Repost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="198"/>
        <source>Delete Repost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="209"/>
        <source>Quote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="218"/>
        <source>View Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="236"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfilePage</name>
    <message>
        <location filename="../assets/ProfilePage.qml" line="124"/>
        <source>Following</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="137"/>
        <source>Followers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="150"/>
        <source>Posts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="163"/>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="179"/>
        <source>Unfollow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="179"/>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="192"/>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="192"/>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="205"/>
        <source>Unblock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="205"/>
        <source>Block</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RefreshItem</name>
    <message>
        <location filename="../assets/RefreshItem.qml" line="29"/>
        <source>Load Newer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <location filename="../assets/SettingsPage.qml" line="26"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="45"/>
        <source>Unified Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="50"/>
        <source>Include mentions in home stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="82"/>
        <source>Use CC on Reply All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="87"/>
        <source>Additional mentions follow /</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamTab</name>
    <message>
        <location filename="../assets/StreamTab.qml" line="137"/>
        <source>New Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="151"/>
        <source>To Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="179"/>
        <source>To Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="166"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../assets/main.qml" line="35"/>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="42"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="68"/>
        <location filename="../assets/main.qml" line="72"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="90"/>
        <location filename="../assets/main.qml" line="94"/>
        <source>Mentions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="112"/>
        <location filename="../assets/main.qml" line="116"/>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="134"/>
        <location filename="../assets/main.qml" line="138"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> Goober_0_9_0.tar.gz: goober-bb10/translations/Goober.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>LoginSheet</name>
    <message>
        <location filename="../assets/LoginSheet.qml" line="47"/>
        <source>Sign In</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetImageManager</name>
    <message>
        <location filename="../src/netimagemanager.cpp" line="177"/>
        <source>SSL errors received</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/netimagemanager.cpp" line="178"/>
        <source>We have received information about a security breach in the protocol. Press &quot;OK&quot; to terminate the application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewPostSheet</name>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="35"/>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="44"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/NewPostSheet.qml" line="50"/>
        <source>New Post</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostItem</name>
    <message>
        <location filename="../assets/PostItem.qml" line="226"/>
        <source>Reply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="235"/>
        <source>Reply All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="245"/>
        <source>Delete Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="245"/>
        <source>Add Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="256"/>
        <source>Delete Repost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="256"/>
        <source>Repost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="267"/>
        <source>Quote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="276"/>
        <source>View Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="283"/>
        <source>Copy text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/PostItem.qml" line="313"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfilePage</name>
    <message>
        <location filename="../assets/ProfilePage.qml" line="145"/>
        <location filename="../assets/ProfilePage.qml" line="218"/>
        <source>Following</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="158"/>
        <location filename="../assets/ProfilePage.qml" line="233"/>
        <source>Followers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="171"/>
        <location filename="../assets/ProfilePage.qml" line="205"/>
        <source>Posts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="184"/>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="250"/>
        <source>Unfollow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="250"/>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="263"/>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="263"/>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="276"/>
        <source>Unblock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/ProfilePage.qml" line="276"/>
        <source>Block</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RefreshItem</name>
    <message>
        <location filename="../assets/RefreshItem.qml" line="29"/>
        <source>Load Newer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <location filename="../assets/SettingsPage.qml" line="26"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="45"/>
        <source>Unified Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="50"/>
        <source>Include mentions in home stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="82"/>
        <source>Use CC on Reply All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="87"/>
        <source>Additional mentions follow /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="121"/>
        <source>Hide photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="126"/>
        <source>Hide embeded photos in timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="160"/>
        <source>Hide avatars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="165"/>
        <source>Hide avatar images in timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="195"/>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="197"/>
        <source>Bright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/SettingsPage.qml" line="202"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamTab</name>
    <message>
        <location filename="../assets/StreamTab.qml" line="170"/>
        <source>New Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="184"/>
        <source>To Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="212"/>
        <source>To Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/StreamTab.qml" line="199"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserItem</name>
    <message>
        <location filename="../assets/UserItem.qml" line="67"/>
        <source>Unfollow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/UserItem.qml" line="67"/>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../assets/main.qml" line="35"/>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="42"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="74"/>
        <location filename="../assets/main.qml" line="78"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="96"/>
        <location filename="../assets/main.qml" line="100"/>
        <source>Mentions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="118"/>
        <location filename="../assets/main.qml" line="122"/>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../assets/main.qml" line="140"/>
        <location filename="../assets/main.qml" line="144"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
